@@ -37,11 +37,11 @@ func FuzzIntotoCreateProposedEntry(f *testing.F) {
 	f.Fuzz(func(t *testing.T, propsData []byte) {
 		initter.Do(fuzzUtils.SetFuzzLogger)
 
-		version := "0.0.2"
+		version := "0.0.1"
 
 		ff := fuzz.NewConsumer(propsData)
 
-		props, cleanup, err := fuzzUtils.CreateProps(ff, "intotoV002")
+		props, cleanup, err := fuzzUtils.CreateProps(ff, "intotoV001")
 		if err != nil {
 			t.Skip()
 		}
@@ -79,15 +79,15 @@ func FuzzIntotoUnmarshalAndCanonicalize(f *testing.F) {
 
 		ff := fuzz.NewConsumer(entryData)
 
-		targetV002 := &models.IntotoV002Schema{}
+		targetV001 := &models.IntotoV001Schema{}
 
-		if err := ff.GenerateStruct(targetV002); err != nil {
+		if err := ff.GenerateStruct(targetV001); err != nil {
 			t.Skip()
 		}
 
 		targetEntry := &models.Intoto{
 			APIVersion: conv.Pointer(APIVERSION),
-			Spec:       targetV002,
+			Spec:       targetV001,
 		}
 
 		ei, err := types.UnmarshalEntry(targetEntry)
@@ -101,8 +101,8 @@ func FuzzIntotoUnmarshalAndCanonicalize(f *testing.F) {
 	})
 }
 
-// New: fuzz the direct decoder map fast-path and typed-model inputs
-func FuzzIntotoDecodeEntryDirectMapAndRaw(f *testing.F) {
+// New: fuzz the direct decoder map fast-path and raw JSON fallbacks
+func FuzzIntotoV001DecodeEntryDirectMapAndRaw(f *testing.F) {
 	f.Fuzz(func(t *testing.T, data []byte) {
 		initter.Do(fuzzUtils.SetFuzzLogger)
 		ff := fuzz.NewConsumer(data)
@@ -119,38 +119,30 @@ func FuzzIntotoDecodeEntryDirectMapAndRaw(f *testing.F) {
 		var input any
 		switch choice {
 		case 0:
-			// Construct a minimal map resembling the schema
 			m := map[string]any{}
+			if b, _ := ff.GetBool(); b {
+				m["publicKey"] = toB64(256)
+			}
 			content := map[string]any{}
-			env := map[string]any{}
 			if b, _ := ff.GetBool(); b {
-				env["payloadType"] = "application/vnd.in-toto+json"
-				env["payload"] = toB64(512)
-			}
-			if b, _ := ff.GetBool(); b {
-				env["signatures"] = []any{map[string]any{"keyid": "k", "sig": toB64(128), "publicKey": toB64(256)}}
-			}
-			if len(env) > 0 {
-				content["envelope"] = env
+				content["envelope"] = string(append([]byte(`{"payload":"`), []byte(toB64(128))...))
 			}
 			if b, _ := ff.GetBool(); b {
 				content["hash"] = map[string]any{"algorithm": "sha256", "value": "deadbeef"}
 			}
 			if b, _ := ff.GetBool(); b {
-				content["payloadHash"] = map[string]any{"algorithm": "sha256", "value": "deadbeef"}
-			}
-			if len(content) > 0 {
-				m["content"] = content
+				content["payloadHash"] = map[string]any{"algorithm": "sha256", "value": "cafebabe"}
 			}
+			m["content"] = content
 			input = m
 		case 1:
-			mdl := &models.IntotoV002Schema{}
+			mdl := &models.IntotoV001Schema{}
 			if err := ff.GenerateStruct(mdl); err != nil {
 				t.Skip()
 			}
 			input = mdl
 		}
-		entry := &V002Entry{}
+		entry := &V001Entry{}
 		if err := DecodeEntry(input, &entry.IntotoObj); err != nil {
 			t.Skip()
 		}
